@@ -157,6 +157,12 @@ call_returned (GObject *object,
   ret = g_dbus_connection_call_finish (G_DBUS_CONNECTION (object), result, &error);
   if (error)
     {
+      if (call->cancelled_id)
+        {
+          g_signal_handler_disconnect (g_task_get_cancellable (call->task), call->cancelled_id);
+          call->cancelled_id = 0;
+        }
+
       g_task_return_error (call->task, error);
       file_call_free (call);
     }
@@ -240,27 +246,27 @@ open_file (FileCall *call)
  *
  * Asks the user to open one or more files.
  *
- * The format for the @filters argument is a(sa(us)).
+ * The format for the @filters argument is `a(sa(us))`.
  * Each item in the array specifies a single filter to offer to the user.
- * The first string is a user-visible name for the filter. The a(us)
+ * The first string is a user-visible name for the filter. The `a(us)`
  * specifies a list of filter strings, which can be either a glob pattern
  * (indicated by 0) or a mimetype (indicated by 1).
  * 
- * Example: [('Images', [(0, '*.ico'), (1, 'image/png')]), ('Text', [(0, '*.txt')])]
+ * Example: `[('Images', [(0, '*.ico'), (1, 'image/png')]), ('Text', [(0, '*.txt')])]`
  *
- * The format for the @choices argument is a(ssa(ss)s).
+ * The format for the @choices argument is `a(ssa(ss)s)`.
  * For each element, the first string is an ID that will be returned
  * with the response, te second string is a user-visible label. The
- * a(ss) is the list of choices, each being a is an ID and a
+ * `a(ss)` is the list of choices, each being a is an ID and a
  * user-visible label. The final string is the initial selection,
- * or "", to let the portal decide which choice will be initially selected.
+ * or `""`, to let the portal decide which choice will be initially selected.
  * None of the strings, except for the initial selection, should be empty.
  * 
  * As a special case, passing an empty array for the list of choices
  * indicates a boolean choice that is typically displayed as a check
- * button, using "true" and "false" as the choices.
+ * button, using `"true"` and `"false"` as the choices.
  *
- * Example: [('encoding', 'Encoding', [('utf8', 'Unicode (UTF-8)'), ('latin15', 'Western')], 'latin15'), ('reencode', 'Reencode', [], 'false')]
+ * Example: `[('encoding', 'Encoding', [('utf8', 'Unicode (UTF-8)'), ('latin15', 'Western')], 'latin15'), ('reencode', 'Reencode', [], 'false')]`
  *
  * When the request is done, @callback will be called. You can then
  * call [method@Portal.open_file_finish] to get the results.
@@ -306,9 +312,10 @@ xdp_portal_open_file (XdpPortal *portal,
  * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
- * Finishes the open-file request, and returns
- * the result in the form of a [struct@GLib.Variant] dictionary containing
- * the following fields:
+ * Finishes the open-file request
+ *
+ * Returns the result in the form of a [struct@GLib.Variant] dictionary
+ * containing the following fields:
  *
  * - uris `as`: an array of strings containing the uris of selected files
  * - choices `a(ss)`: an array of pairs of strings, the first string being the
@@ -322,14 +329,11 @@ xdp_portal_open_file_finish (XdpPortal *portal,
                              GAsyncResult *result,
                              GError **error)
 {
-  GVariant *ret;
-
   g_return_val_if_fail (XDP_IS_PORTAL (portal), NULL);
   g_return_val_if_fail (g_task_is_valid (result, portal), NULL);
   g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == xdp_portal_open_file, NULL);
 
-  ret = g_task_propagate_pointer (G_TASK (result), error);
-  return ret ? g_variant_ref (ret) : NULL;
+  return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 /**
@@ -403,9 +407,10 @@ xdp_portal_save_file (XdpPortal *portal,
  * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
- * Finishes the save-file request, and returns
- * the result in the form of a [struct@GLib.Variant] dictionary containing
- * the following fields:
+ * Finishes the save-file request.
+ *
+ * Returns the result in the form of a [struct@GLib.Variant] dictionary
+ * containing the following fields:
  *
  * - uris `(as)`: an array of strings containing the uri of the selected file
  * - choices `a(ss)`: an array of pairs of strings, the first string being the
@@ -419,14 +424,11 @@ xdp_portal_save_file_finish (XdpPortal *portal,
                              GAsyncResult *result,
                              GError **error)
 {
-  GVariant *ret;
-
   g_return_val_if_fail (XDP_IS_PORTAL (portal), NULL);
   g_return_val_if_fail (g_task_is_valid (result, portal), NULL);
   g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == xdp_portal_save_file, NULL);
 
-  ret = g_task_propagate_pointer (G_TASK (result), error);
-  return ret ? g_variant_ref (ret) : NULL;
+  return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 /**
@@ -443,12 +445,12 @@ xdp_portal_save_file_finish (XdpPortal *portal,
  * @callback: (scope async): a callback to call when the request is done
  * @data: (closure): data to pass to @callback
  *
- * Asks for a folder as a location to save one or more files. The
- * names of the files will be used as-is and appended to the selected
- * folder's path in the list of returned files. If the selected folder
- * already contains a file with one of the given names, the portal may
- * prompt or take some other action to construct a unique file name and
- * return that instead.
+ * Asks for a folder as a location to save one or more files.
+ *
+ * The names of the files will be used as-is and appended to the selected
+ * folder's path in the list of returned files. If the selected folder already
+ * contains a file with one of the given names, the portal may prompt or take
+ * some other action to construct a unique file name and return that instead.
  *
  * The format for the @choices argument is the same as for [method@Portal.open_file].
  *
@@ -498,9 +500,10 @@ xdp_portal_save_files (XdpPortal *portal,
  * @result: a [iface@Gio.AsyncResult]
  * @error: return location for an error
  *
- * Finishes the save-files request, and returns
- * the result in the form of a [struct@GLib.Variant] dictionary containing
- * the following fields:
+ * Finishes the save-files request.
+ *
+ * Returns the result in the form of a [struct@GLib.Variant] dictionary
+ * containing the following fields:
  *
  * - uris `(as)`: an array of strings containing the uri corresponding to each
  *   file passed to the save-files request, in the same order. Note that the
@@ -517,12 +520,9 @@ xdp_portal_save_files_finish (XdpPortal *portal,
                               GAsyncResult *result,
                               GError **error)
 {
-  GVariant *ret;
-
   g_return_val_if_fail (XDP_IS_PORTAL (portal), NULL);
   g_return_val_if_fail (g_task_is_valid (result, portal), NULL);
   g_return_val_if_fail (g_task_get_source_tag (G_TASK (result)) == xdp_portal_save_files, NULL);
 
-  ret = g_task_propagate_pointer (G_TASK (result), error);
-  return ret ? g_variant_ref (ret) : NULL;
+  return g_task_propagate_pointer (G_TASK (result), error);
 }
