@@ -19,6 +19,7 @@
 
 #pragma once
 
+#include "glib-backports.h"
 #include "parent-private.h"
 #include "portal-helpers.h"
 
@@ -49,6 +50,8 @@ struct _XdpPortal {
 
   /* notification */
   guint action_invoked_signal;
+  guint notification_interface_version;
+  GVariant *supported_notification_options;
 
   /* screencast */
   guint screencast_interface_version;
