@@ -512,16 +512,10 @@ xdp_portal_create_screencast_session_finish (XdpPortal *portal,
                                              GAsyncResult *result,
                                              GError **error)
 {
-  XdpSession *session;
-
   g_return_val_if_fail (XDP_IS_PORTAL (portal), NULL);
   g_return_val_if_fail (g_task_is_valid (result, portal), NULL);
 
-  session = g_task_propagate_pointer (G_TASK (result), error);
-  if (session)
-    return g_object_ref (session);
-  else
-    return NULL;
+  return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 /**
@@ -629,17 +623,10 @@ xdp_portal_create_remote_desktop_session_finish (XdpPortal *portal,
                                                  GAsyncResult *result,
                                                  GError **error)
 {
-  XdpSession *session;
-
   g_return_val_if_fail (XDP_IS_PORTAL (portal), NULL);
   g_return_val_if_fail (g_task_is_valid (result, portal), NULL);
 
-  session = g_task_propagate_pointer (G_TASK (result), error);
-
-  if (session)
-    return g_object_ref (session);
-  else
-    return NULL;
+  return g_task_propagate_pointer (G_TASK (result), error);
 }
 
 
